@@ -1,12 +1,8 @@
-import json
 import logging
 import logging.config
-import sys
 from functools import wraps
 
 import yaml
-from yaml.parser import ParserError
-from yaml.scanner import ScannerError
 
 from .builders import LogTextBuilder
 
@@ -30,12 +26,11 @@ class FlaskLogging:
         """
         return self._conf
 
-    def init_app(self, app, builder=LogTextBuilder(), **kwargs):
+    def init_app(self, app, builder=LogTextBuilder()):
         """
 
         :param app: Flask app instance
         :param builder:
-        :param kwargs: extra logging configuration
         """
         if not hasattr(app, 'extensions'):
             app.extensions = dict()
@@ -47,14 +42,17 @@ class FlaskLogging:
             app.before_request_funcs.setdefault(None, []).append(builder.dump_request)
             app.after_request_funcs.setdefault(None, []).append(builder.dump_response)
 
-        if 'LOG_FILE_CONF' in app.config:
+        if app.config['LOG_FILE_CONF']:
             try:
-                self.conf_from_file(app.config['LOG_FILE_CONF'])
-            except OSError as exc:
+                with open(app.config['LOG_FILE_CONF']) as f:
+                    self._conf = yaml.safe_load(f)
+            except (OSError, IOError, yaml.YAMLError) as exc:
                 app.logger.exception(exc, stack_info=False)
+        elif app.config['LOGGING']:
+            self._conf = app.config['LOGGING']
 
+        if self._conf:
             try:
-                self._conf.update(kwargs)
                 logging.config.dictConfig(self._conf)
                 app.logger = logging.getLogger(app.config['LOG_LOGGER_NAME'])
             except ValueError as exc:
@@ -62,27 +60,7 @@ class FlaskLogging:
                 app.logger.error('the configuration below\n{}'.format(self._conf))
                 app.logger.exception(exc, stack_info=False)
         else:
-            app.logger.warning("No 'LOG_FILE_CONF' provided using default configuration")
-
-        if app.config.get('DEBUG') is True:
-            app.logger.setLevel('DEBUG')
-            self.set_werkzeug_handlers(app.logger.handlers)
-
-    def conf_from_file(self, filename):
-        """
-
-        :param filename:
-        """
-        with open(filename) as f:
-            try:
-                self._conf = yaml.safe_load(f)
-            except (ParserError, ScannerError) as yex:
-                try:
-                    self._conf = json.load(f)
-                except (TypeError, json.JSONDecodeError) as jex:
-                    print(yex, file=sys.stderr)
-                    print(jex, file=sys.stderr)
-                    sys.exit(1)
+            app.logger.warning("No logging configuration provided using default configuration")
 
     @staticmethod
     def disabled(filter_class, loggers=None, **options):
@@ -123,6 +101,8 @@ class FlaskLogging:
 
         param app: Flask app instance
         """
+        app.config.setdefault('LOG_FILE_CONF', None)
+        app.config.setdefault('LOGGING', None)
         app.config.setdefault('LOG_REQ_HEADERS', [])
         app.config.setdefault('LOG_RESP_HEADERS', [])
         app.config.setdefault('LOG_SKIP_DUMP', not app.config.get('DEBUG'))
@@ -133,14 +113,3 @@ class FlaskLogging:
             app.config['LOG_APP_NAME'],
             app.config.get('FLASK_ENV') or 'development'
         ))
-
-    @staticmethod
-    def set_werkzeug_handlers(handlers):
-        """
-
-        :param handlers:
-        """
-        werkzeug_logger = logging.getLogger('werkzeug')
-        werkzeug_logger.setLevel(logging.DEBUG)
-        for hdl in handlers:
-            werkzeug_logger.addHandler(hdl)
